---
sidebar_label: ndarray
title: data_structures.predefined.ndarray
---

## Ndarray Objects

```python
class Ndarray(DataStructure)
```

This class serializes numpy ndarrays

soil.data(my_ndarray) will create a nd_array automatically.

#### unserialize

```python
 | @staticmethod
 | unserialize(json_data, metadata)
```

Deprecated method. It can be removed in a few months.

